==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=he
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'הוספת מסמך',
	'bouton_ajouter_image' => 'הוספת תמונה',
	'bouton_ajouter_image_document' => 'הוסף תמונה או מסמך ',

	// D
	'double_clic_inserer_doc' => 'הקלק פעמיים על מנת להוסיף קיצור דרך זה לטקסט',

	// E
	'entree_dimensions' => 'גודל :',
	'entree_titre_document' => 'כתורת של המסמך :',
	'entree_titre_image' => 'כתורת של התמונה :',

	// I
	'image_tourner_180' => 'רוטציה 180°',
	'image_tourner_droite' => 'רוטציה 90° ימינה',
	'image_tourner_gauche' => 'רוטציה 90° שמאלה',
	'info_document' => 'מסמך',
	'info_document_indisponible' => 'המסמך אינו נגיש',
	'info_documents' => 'מסמכים',
	'info_inclusion_directe' => ':הכללה ישירה',
	'info_inclusion_vignette' => ':לכלול גפנית',
	'info_installer_tous_documents' => 'התקן את כל המסמכים',
	'info_logo_max_taille' => 'גודל הלוגואים צריך להיות פחות מ@maxi@ (גודל הקובץ הנוכחי @actuel@).',
	'info_portfolio' => 'תיק',
	'info_telecharger' => 'העלה מהמחשב שלך:',

	// T
	'texte_documents_joints' => 'Vous pouvez autoriser l’ajout de documents (fichiers bureautiques, images,
 multimédia, etc.) aux articles et/ou aux rubriques. Ces fichiers
 peuvent ensuite être référencés dans
 l’article, ou affichés séparément.', # MODIF

	// U
	'upload_fichier_zip' => 'קובץ ZIP',
	'upload_fichier_zip_texte' => 'הקובץ שאתה מציע להתקין הנו קובץ ZIP.',
	'upload_fichier_zip_texte2' => 'קובץ זה יכול להיות :',
	'upload_limit' => 'קובץ זה גדול מדי בשביל השרת ; הגודל המרבי <i>uלהעלה</i> הוא @max@.',
	'upload_zip_decompacter' => 'מחולץ וכל אלמנט הנכלל בו הנו מותקן באתר. להלן הקבצים שיותקנו באתר :',
	'upload_zip_telquel' => 'מותקן כפי שהוא, בשאר הוא ארכיון מחולץ ;'
);

==> spip_4.4.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_he.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=he
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'הוספת מסמך',
	'bouton_ajouter_image' => 'הוספת תמונה',
	'bouton_ajouter_image_document' => 'הוסף תמונה או מסמך ',

	// D
	'double_clic_inserer_doc' => 'הקלק פעמיים על מנת להוסיף קיצור דרך זה לטקסט',

	// E
	'entree_dimensions' => 'גודל :',
	'entree_titre_document' => 'כתורת של המסמך :',
	'entree_titre_image' => 'כתורת של התמונה :',

	// I
	'image_tourner_180' => 'רוטציה 180°',
	'image_tourner_droite' => 'רוטציה 90° ימינה',
	'image_tourner_gauche' => 'רוטציה 90° שמאלה',
	'info_document' => 'מסמך',
	'info_document_indisponible' => 'המסמך אינו נגיש',
	'info_documents' => 'מסמכים',
	'info_inclusion_directe' => ':הכללה ישירה',
	'info_inclusion_vignette' => ':לכלול גפנית',
	'info_installer_tous_documents' => 'התקן את כל המסמכים',
	'info_logo_max_taille' => 'גודל הלוגואים צריך להיות פחות מ@maxi@ (גודל הקובץ הנוכחי @actuel@).',
	'info_portfolio' => 'תיק',
	'info_telecharger' => 'העלה מהמחשב שלך:',

	// T
	'texte_documents_joints' => 'Vous pouvez autoriser l’ajout de documents (fichiers bureautiques, images,
 multimédia, etc.) aux articles et/ou aux rubriques. Ces fichiers
 peuvent ensuite être référencés dans
 l’article, ou affichés séparément.', # MODIF

	// U
	'upload_fichier_zip' => 'קובץ ZIP',
	'upload_fichier_zip_texte' => 'הקובץ שאתה מציע להתקין הנו קובץ ZIP.',
	'upload_fichier_zip_texte2' => 'קובץ זה יכול להיות :',
	'upload_limit' => 'קובץ זה גדול מדי בשביל השרת ; הגודל המרבי <i>uלהעלה</i> הוא @max@.',
	'upload_zip_decompacter' => 'מחולץ וכל אלמנט הנכלל בו הנו מותקן באתר. להלן הקבצים שיותקנו באתר :',
	'upload_zip_telquel' => 'מותקן כפי שהוא, בשאר הוא ארכיון מחולץ ;',
];
